@@ -5,6 +5,7 @@ import aiohttp
 from yarl import URL
 
 from .abc import (
+    AbstractDeleteProgress,
     AbstractDockerImageProgress,
     AbstractFileProgress,
     AbstractRecursiveFileProgress,
@@ -12,6 +13,7 @@ from .abc import (
     ImageProgressPush,
     ImageProgressStep,
     StorageProgressComplete,
+    StorageProgressDelete,
     StorageProgressEnterDir,
     StorageProgressFail,
     StorageProgressLeaveDir,
@@ -20,19 +22,20 @@ from .abc import (
 )
 from .blob_storage import Blob, BlobListing, BlobStorage, BucketListing, PrefixListing
 from .client import Client, Preset
-from .config import Config, ConfigError
+from .config import Config
 from .config_factory import (
     CONFIG_ENV_NAME,
     DEFAULT_API_URL,
     DEFAULT_CONFIG_PATH,
     Factory,
 )
-from .core import (
-    DEFAULT_TIMEOUT,
+from .core import DEFAULT_TIMEOUT
+from .errors import (
     AuthenticationError,
     AuthError,
     AuthorizationError,
     ClientError,
+    ConfigError,
     IllegalArgumentError,
     ResourceNotFound,
     ServerNotAvailable,
@@ -48,16 +51,19 @@ from .jobs import (
     JobStatusHistory,
     JobTelemetry,
     Resources,
+    SecretFile,
     StdStream,
     Volume,
 )
 from .parser import Parser
 from .parsing_utils import LocalImage, RemoteImage, TagOption
+from .plugins import PluginManager
+from .secrets import Secret, Secrets
 from .server_cfg import Cluster
 from .storage import FileStatus, FileStatusType, Storage
 from .tracing import gen_trace_id
 from .users import Action, Permission, Share, Users
-from .utils import _ContextManager
+from .utils import _ContextManager, find_project_root
 
 
 __all__ = (
@@ -73,6 +79,7 @@ __all__ = (
     "Resources",
     "StdStream",
     "Volume",
+    "SecretFile",
     "HTTPPort",
     "Users",
     "Action",
@@ -98,6 +105,7 @@ __all__ = (
     "ServerNotAvailable",
     "AbstractFileProgress",
     "AbstractRecursiveFileProgress",
+    "AbstractDeleteProgress",
     "AbstractDockerImageProgress",
     "StorageProgressStart",
     "StorageProgressComplete",
@@ -105,6 +113,7 @@ __all__ = (
     "StorageProgressFail",
     "StorageProgressEnterDir",
     "StorageProgressLeaveDir",
+    "StorageProgressDelete",
     "ImageProgressPull",
     "ImageProgressPush",
     "ImageProgressStep",
@@ -122,6 +131,10 @@ __all__ = (
     "Cluster",
     "Images",
     "Parser",
+    "Secrets",
+    "Secret",
+    "PluginManager",
+    "find_project_root",
 )
 
 
@@ -140,7 +153,7 @@ async def login(
     *,
     url: URL = DEFAULT_API_URL,
     path: Optional[Path] = None,
-    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT
+    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT,
 ) -> None:
     await Factory(path).login(show_browser_cb, url=url, timeout=timeout)
 
@@ -150,7 +163,7 @@ async def login_with_token(
     *,
     url: URL = DEFAULT_API_URL,
     path: Optional[Path] = None,
-    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT
+    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT,
 ) -> None:
     await Factory(path).login_with_token(token, url=url, timeout=timeout)
 
@@ -160,7 +173,7 @@ async def login_headless(
     *,
     url: URL = DEFAULT_API_URL,
     path: Optional[Path] = None,
-    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT
+    timeout: aiohttp.ClientTimeout = DEFAULT_TIMEOUT,
 ) -> None:
     await Factory(path).login_headless(get_auth_code_cb, url=url, timeout=timeout)
 
