@@ -12,19 +12,18 @@ from pathlib import Path
 from types import MappingProxyType
 from typing import Any, Dict, Iterator, List, Mapping, Optional, Set, Tuple, Union
 
+import pkg_resources
 import toml
 from yarl import URL
 
 import neuromation
 
 from .core import _Core
+from .errors import ConfigError
 from .login import AuthTokenClient, _AuthConfig, _AuthToken
+from .plugins import PluginManager
 from .server_cfg import Cluster, Preset, _ServerConfig, get_server_config
-from .utils import NoPublicConstructor, flat
-
-
-class ConfigError(RuntimeError):
-    pass
+from .utils import NoPublicConstructor, find_project_root, flat
 
 
 WIN32 = sys.platform == "win32"
@@ -170,6 +169,11 @@ class Config(metaclass=NoPublicConstructor):
         cluster = self._config_data.clusters[self._config_data.cluster_name]
         return cluster.registry_url
 
+    @property
+    def secrets_url(self) -> URL:
+        cluster = self._config_data.clusters[self._config_data.cluster_name]
+        return cluster.secrets_url
+
     async def token(self) -> str:
         token = self._config_data.auth_token
         if not token.is_expired():
@@ -200,27 +204,7 @@ class Config(metaclass=NoPublicConstructor):
         ).decode("ascii")
 
     async def get_user_config(self) -> Mapping[str, Any]:
-        # TODO: search in several locations (HOME+curdir),
-        # merge found configs
-        filename = self._path / "user.toml"
-        if not filename.exists():
-            # Empty global configuration
-            config: Mapping[str, Any] = {}
-        elif not filename.is_file():
-            raise ConfigError(f"User config {filename} should be a regular file")
-        else:
-            config = _load_file(filename)
-        folder = Path.cwd()
-        while True:
-            filename = folder / ".neuro.toml"
-            if filename.exists() and filename.is_file():
-                local_config = _load_file(filename)
-                return _merge_user_configs(config, local_config)
-            if folder == folder.parent:
-                # No local config is found
-                return config
-            else:
-                folder = folder.parent
+        return await load_user_config(self._path)
 
     @contextlib.contextmanager
     def _open_db(self) -> Iterator[sqlite3.Connection]:
@@ -228,6 +212,27 @@ class Config(metaclass=NoPublicConstructor):
             yield db
 
 
+async def load_user_config(path: Path) -> Mapping[str, Any]:
+    # TODO: search in several locations (HOME+curdir),
+    # merge found configs
+    filename = path / "user.toml"
+    if not filename.exists():
+        # Empty global configuration
+        config: Mapping[str, Any] = {}
+    elif not filename.is_file():
+        raise ConfigError(f"User config {filename} should be a regular file")
+    else:
+        config = _load_file(filename)
+    try:
+        project_root = find_project_root()
+    except ConfigError:
+        return config
+    else:
+        filename = project_root / ".neuro.toml"
+        local_config = _load_file(filename)
+        return _merge_user_configs(config, local_config)
+
+
 @contextlib.contextmanager
 def _open_db_rw(path: Path) -> Iterator[sqlite3.Connection]:
     path.mkdir(0o700, parents=True, exist_ok=True)
@@ -341,6 +346,7 @@ def _deserialize_clusters(payload: Dict[str, Any]) -> Dict[str, Cluster]:
             storage_url=URL(cluster_config["storage_url"]),
             users_url=URL(cluster_config["users_url"]),
             monitoring_url=URL(cluster_config["monitoring_url"]),
+            secrets_url=URL(cluster_config["secrets_url"]),
             presets=dict(
                 _deserialize_resource_preset(data)
                 for data in cluster_config.get("presets", [])
@@ -448,6 +454,7 @@ def _serialize_clusters(clusters: Mapping[str, Cluster]) -> str:
             "storage_url": str(cluster.storage_url),
             "users_url": str(cluster.users_url),
             "monitoring_url": str(cluster.monitoring_url),
+            "secrets_url": str(cluster.secrets_url),
             "presets": [
                 _serialize_resource_preset(name, preset)
                 for name, preset in cluster.presets.items()
@@ -567,21 +574,19 @@ def _validate_user_config(
     #
     # Since currently CLI is the only API client that reads user config data, API
     # validates it.
-    #
-    # Later, after possible introduction of plugin subsystem the validation should
-    # be extended by plugin-provided rules.  That will be done by providing
-    # additional API for describing new supported config sections, keys and values.
-    # Right now this functionality is skipped for the sake of simplicity.
-    _check_sections(config, {"alias", "job", "storage"}, filename)
-    _check_section(
-        config, "job", {"ps-format": str, "life-span": str}, filename,
-    )
-    _check_section(
-        config,
-        "storage",
-        {"cp-exclude": (list, str), "cp-exclude-from-files": (list, str)},
-        filename,
-    )
+    plugin_manager = PluginManager()
+    plugin_manager.config.define_str("job", "ps-format")
+    plugin_manager.config.define_str("job", "life-span")
+    plugin_manager.config.define_str_list("storage", "cp-exclude")
+    plugin_manager.config.define_str_list("storage", "cp-exclude-from-files")
+    for entry_point in pkg_resources.iter_entry_points("neuro_api"):
+        entry_point.load()(plugin_manager)
+    config_spec = plugin_manager.config._get_spec()
+
+    # Alias section uses different validation
+    _check_sections(config, set(config_spec.keys()) | {"alias"}, filename)
+    for section_name, section_validator in config_spec.items():
+        _check_section(config, section_name, section_validator, filename)
     aliases = config.get("alias", {})
     for key, value in aliases.items():
         # check keys and values
