@@ -43,6 +43,7 @@ from .images import (
 )
 from .parser import Parser, Volume
 from .parsing_utils import LocalImage, RemoteImage, _as_repo_str, _is_in_neuro_registry
+from .server_cfg import Preset
 from .url_utils import normalize_secret_uri, normalize_storage_path_uri
 from .utils import NoPublicConstructor, asynccontextmanager
 
@@ -564,6 +565,21 @@ class Jobs(metaclass=NoPublicConstructor):
         async with self._core.request("POST", url, auth=auth) as resp:
             resp
 
+    async def get_capacity(self, presets: Mapping[str, Preset]) -> Mapping[str, int]:
+        url = self._config.monitoring_url / "available"
+        auth = await self._config._api_auth()
+        payload: Dict[str, Any] = {}
+        for name, preset in presets.items():
+            payload[name] = {
+                "cpu": preset.cpu,
+                "memory_mb": preset.memory_mb,
+                "gpu": preset.gpu or 0,
+                "gpu_model": preset.gpu_model or "",
+                "is_preemptible": preset.is_preemptible,
+            }
+        async with self._core.request("POST", url, auth=auth, json=payload) as resp:
+            return await resp.json()
+
 
 #  ############## Internal helpers ###################
 
@@ -702,6 +718,14 @@ def _container_to_api(container: Container, config: Config) -> Dict[str, Any]:
     return primitive
 
 
+def _calc_status(stat: str) -> JobStatus:
+    # Forward-compatible support for CANCELLED status
+    try:
+        return JobStatus(stat)
+    except ValueError:
+        return JobStatus.UNKNOWN
+
+
 def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescription:
     container = _container_from_api(res["container"], parse)
     owner = res["owner"]
@@ -710,7 +734,8 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
     tags = res.get("tags", ())
     description = res.get("description")
     history = JobStatusHistory(
-        status=JobStatus(res["history"].get("status", "unknown")),
+        # Forward-compatible support for CANCELLED status
+        status=_calc_status(res["history"].get("status", "unknown")),
         reason=res["history"].get("reason", ""),
         description=res["history"].get("description", ""),
         created_at=_parse_datetime(res["history"].get("created_at")),
@@ -729,7 +754,7 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
         max_run_time_minutes * 60.0 if max_run_time_minutes is not None else None
     )
     return JobDescription(
-        status=JobStatus(res["status"]),
+        status=_calc_status(res["status"]),
         id=res["id"],
         owner=owner,
         cluster_name=cluster_name,
