@@ -4,7 +4,8 @@ from typing import Any, Dict, Mapping, Optional
 import aiohttp
 from yarl import URL
 
-from .login import AuthException, _AuthConfig
+from .errors import AuthException
+from .login import _AuthConfig
 
 
 @dataclass(frozen=True)
@@ -25,6 +26,7 @@ class Cluster:
     storage_url: URL
     users_url: URL
     monitoring_url: URL
+    secrets_url: URL
     presets: Mapping[str, Preset]
 
 
@@ -34,10 +36,6 @@ class _ServerConfig:
     clusters: Mapping[str, Cluster]
 
 
-class ConfigLoadException(Exception):
-    pass
-
-
 def _parse_cluster_config(payload: Dict[str, Any]) -> Cluster:
     presets: Dict[str, Preset] = {}
     for data in payload["resource_presets"]:
@@ -61,6 +59,7 @@ def _parse_cluster_config(payload: Dict[str, Any]) -> Cluster:
         storage_url=URL(payload["storage_url"]),
         users_url=URL(payload["users_url"]),
         monitoring_url=URL(payload["monitoring_url"]),
+        secrets_url=URL(payload["secrets_url"]),
         presets=presets,
     )
     return cluster_config
