@@ -16,11 +16,13 @@ from click import style, unstyle
 from yarl import URL
 
 from neuromation.api import (
+    AbstractDeleteProgress,
     AbstractRecursiveFileProgress,
     Action,
     FileStatus,
     FileStatusType,
     StorageProgressComplete,
+    StorageProgressDelete,
     StorageProgressEnterDir,
     StorageProgressFail,
     StorageProgressLeaveDir,
@@ -567,6 +569,20 @@ class FilesSorter(str, enum.Enum):
 # progress indicator
 
 
+class DeleteProgress(AbstractDeleteProgress):
+    def __init__(self, root: Root) -> None:
+        self.painter = get_painter(root.color, quote=True)
+
+    def fmt_url(self, url: URL, type: FileStatusType) -> str:
+        return self.painter.paint(str(url), type)
+
+    def delete(self, data: StorageProgressDelete) -> None:
+        url_label = self.fmt_url(
+            data.uri, FileStatusType.DIRECTORY if data.is_dir else FileStatusType.FILE,
+        )
+        click.echo(f"Removed: {url_label}")
+
+
 class BaseStorageProgress(AbstractRecursiveFileProgress):
     @abc.abstractmethod
     def begin(self, src: URL, dst: URL) -> None:  # pragma: no cover
@@ -745,7 +761,7 @@ class TTYProgress(BaseStorageProgress):
 
     def step(self, data: StorageProgressStep) -> None:
         src = self.fmt_str(data.src.name, FileStatusType.FILE)
-        progress = (100 * data.current) / data.size
+        progress = 100 * data.current / data.size if data.size else 100
         current = self.fmt_size(data.current)
         total = self.fmt_size(data.size)
         self.replace(data.src, f"{src} [{progress:.2f}%] {current} of {total}")
