@@ -20,6 +20,7 @@ from neuromation.api.url_utils import _extract_path
 from .const import EX_OSFILE
 from .formatters.storage import (
     BaseFilesFormatter,
+    DeleteProgress,
     FilesSorter,
     LongFilesFormatter,
     SimpleFilesFormatter,
@@ -68,7 +69,20 @@ def storage() -> None:
     show_default=True,
     help="Expand glob patterns in PATHS",
 )
-async def rm(root: Root, paths: Sequence[str], recursive: bool, glob: bool) -> None:
+@option(
+    "-p/-P",
+    "--progress/--no-progress",
+    is_flag=True,
+    default=None,
+    help="Show progress, on by default in TTY mode, off otherwise.",
+)
+async def rm(
+    root: Root,
+    paths: Sequence[str],
+    recursive: bool,
+    glob: bool,
+    progress: Optional[bool],
+) -> None:
     """
     Remove files or directories.
 
@@ -80,9 +94,14 @@ async def rm(root: Root, paths: Sequence[str], recursive: bool, glob: bool) -> N
     neuro rm storage:foo/**/*.tmp
     """
     errors = False
+    show_progress = root.tty if progress is None else progress
+
     for uri in await _expand(paths, root, glob):
         try:
-            await root.client.storage.rm(uri, recursive=recursive)
+            progress_obj = DeleteProgress(root) if show_progress else None
+            await root.client.storage.rm(
+                uri, recursive=recursive, progress=progress_obj
+            )
         except (OSError, ResourceNotFound, IllegalArgumentError) as error:
             log.error(f"cannot remove {uri}: {error}")
             errors = True
@@ -263,21 +282,13 @@ def filter_option(*args: str, flag_value: bool, help: str) -> Callable[[Any], An
     "--exclude",
     "filters",
     flag_value=True,
-    help=(
-        "Exclude files and directories that match the specified pattern. "
-        "The default can be changed using the storage.cp-exclude "
-        'configuration variable documented in "neuro help user-config"'
-    ),
+    help=("Exclude files and directories that match the specified pattern."),
 )
 @filter_option(
     "--include",
     "filters",
     flag_value=False,
-    help=(
-        "Don't exclude files and directories that match the specified pattern. "
-        "The default can be changed using the storage.cp-exclude "
-        'configuration variable documented in "neuro help user-config"'
-    ),
+    help=("Don't exclude files and directories that match the specified pattern."),
 )
 @option(
     "--exclude-from-files",
@@ -318,6 +329,13 @@ async def cp(
     Use /dev/stdin and /dev/stdout file names to copy a file from terminal
     and print the content of file on the storage to console.
 
+    Any number of --exclude and --include options can be passed.  The
+    filters that appear later in the command take precedence over filters
+    that appear earlier in the command.  If neither --exclude nor
+    --include options are specified the default can be changed using the
+    storage.cp-exclude configuration variable documented in
+    "neuro help user-config".
+
     Examples:
 
     # copy local files into remote storage root
@@ -404,7 +422,7 @@ async def cp(
                         dst,
                         update=update,
                         filter=file_filter.match,
-                        ignore_file_names=ignore_file_names,
+                        ignore_file_names=frozenset(ignore_file_names),
                         progress=progress_obj,
                     )
                 else:
