@@ -21,7 +21,12 @@ from neuromation.api import (
     SecretFile,
     Volume,
 )
-from neuromation.api.jobs import INVALID_IMAGE_NAME, _job_description_from_api
+from neuromation.api.jobs import (
+    INVALID_IMAGE_NAME,
+    _calc_status,
+    _job_description_from_api,
+)
+from neuromation.api.server_cfg import Preset
 from tests import _TestServerFactory
 
 
@@ -2115,3 +2120,47 @@ async def test_port_forward_logs_error(
             await asyncio.sleep(0.1)
 
     assert "test error info" in caplog.text
+
+
+def test__calc_status_known() -> None:
+    assert _calc_status("pending") == JobStatus.PENDING
+
+
+def test__calc_status_unknown() -> None:
+    assert _calc_status("something") == JobStatus.UNKNOWN
+
+
+async def test_get_capacity(
+    aiohttp_server: _TestServerFactory, make_client: _MakeClient
+) -> None:
+    async def handler(request: web.Request) -> web.Response:
+        payload = await request.json()
+        assert payload == {
+            "gpu-p": {
+                "cpu": 0.1,
+                "memory_mb": 100,
+                "gpu": 1,
+                "gpu_model": "nvidia-tesla-k80",
+                "is_preemptible": True,
+            }
+        }
+        return web.json_response({"cpu-micro": 10})
+
+    app = web.Application()
+    app.router.add_post("/jobs/available", handler)
+
+    srv = await aiohttp_server(app)
+
+    async with make_client(srv.make_url("/")) as client:
+        result = await client.jobs.get_capacity(
+            {
+                "gpu-p": Preset(
+                    cpu=0.1,
+                    memory_mb=100,
+                    gpu=1,
+                    gpu_model="nvidia-tesla-k80",
+                    is_preemptible=True,
+                )
+            }
+        )
+        assert result == {"cpu-micro": 10}
