@@ -1,4 +1,5 @@
 import asyncio
+import asyncio.subprocess
 import hashlib
 import logging
 import os
@@ -30,6 +31,7 @@ import aiodocker
 import aiohttp
 import pexpect
 import pytest
+from typing_extensions import Final
 from yarl import URL
 
 from neuromation.api import (
@@ -61,7 +63,7 @@ CLIENT_TIMEOUT = aiohttp.ClientTimeout(None, None, NETWORK_TIMEOUT, NETWORK_TIME
 
 log = logging.getLogger(__name__)
 
-job_id_pattern = re.compile(
+JOB_ID_PATTERN: Final = re.compile(
     # pattern for UUID v4 taken here: https://stackoverflow.com/a/38191078
     r"(job-[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12})",
     re.IGNORECASE,
@@ -427,6 +429,27 @@ class Helper:
 
         return args
 
+    async def acli(
+        self,
+        arguments: List[str],
+        *,
+        verbosity: int = 0,
+        network_timeout: float = NETWORK_TIMEOUT,
+    ) -> asyncio.subprocess.Process:
+        __tracebackhide__ = True
+
+        log.info("Run 'neuro %s'", " ".join(arguments))
+
+        # 5 min timeout is overkill
+        proc = await asyncio.create_subprocess_exec(
+            "neuro",
+            *(self._default_args(verbosity, network_timeout) + arguments),
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        return proc
+
     def run_cli(
         self,
         arguments: List[str],
@@ -461,9 +484,9 @@ class Helper:
             start in " ".join(arguments)
             for start in ("submit", "job submit", "run", "job run")
         ):
-            match = job_id_pattern.search(out)
-            if match:
-                self._executed_jobs.append(match.group(1))
+            job_id = self.find_job_id(out)
+            if job_id:
+                self._executed_jobs.append(job_id)
         out = out.strip()
         err = err.strip()
         if verbosity > 0:
@@ -471,6 +494,10 @@ class Helper:
             print(f"neuro stderr: {err}")
         return SysCap(out, err)
 
+    def find_job_id(self, arg: str) -> Optional[str]:
+        match = JOB_ID_PATTERN.search(arg)
+        return match.group(1) if match else None
+
     def pexpect(
         self,
         arguments: List[str],
@@ -600,10 +627,21 @@ class Helper:
 
     kill_job = run_async(akill_job)
 
-    async def acreate_bucket(self, name: str) -> None:
+    async def acreate_bucket(self, name: str, *, wait: bool = False) -> None:
         __tracebackhide__ = True
         async with api_get(timeout=CLIENT_TIMEOUT, path=self._nmrc_path) as client:
             await client.blob_storage.create_bucket(name)
+            if wait:
+                t0 = time()
+                delay = 1
+                while time() - t0 < 30:
+                    try:
+                        await client.blob_storage.list_blobs(name, max_keys=10)
+                        return
+                    except ResourceNotFound:
+                        delay = min(delay * 2, 15)
+                        await asyncio.sleep(delay)
+                raise RuntimeError(f"Bucket {name} doesn't exist after the creation")
 
     create_bucket = run_async(acreate_bucket)
 
@@ -644,8 +682,11 @@ class Helper:
                     and bucket.creation_time < time() - 3600 * 4
                     and bucket.permission in (Action.WRITE, Action.MANAGE)
                 ):
-                    await self.acleanup_bucket(bucket.name)
-                    await self.adelete_bucket(bucket.name)
+                    with suppress(ResourceNotFound):
+                        # bucket can be deleted by another parallel test run,
+                        # ignore ResourceNotFound errors
+                        await self.acleanup_bucket(bucket.name)
+                        await self.adelete_bucket(bucket.name)
 
     @run_async
     async def upload_blob(self, bucket_name: str, key: str, file: Path) -> None:
@@ -792,7 +833,7 @@ def _tmp_bucket_create(
 
     try:
         helper.drop_stale_buckets("neuro-e2e-")
-        helper.create_bucket(tmpbucketname)
+        helper.create_bucket(tmpbucketname, wait=True)
     except AuthorizationError:
         pytest.skip("No permission to create bucket for user E2E_TOKEN")
     yield tmpbucketname, helper
